@@ -11,7 +11,7 @@
 ## usethis namespace: end
 NULL
 
-utils::globalVariables(c("prop"))
+utils::globalVariables(c("prop", "count"))
 
 # \lifecycle{experimental}
 # \lifecycle{maturing}
@@ -23,11 +23,6 @@ utils::globalVariables(c("prop"))
 # \lifecycle{defunct}
 # \lifecycle{archived}
 
-#' @importFrom magrittr %>%
-#' @export
-magrittr::`%>%`
-
-
 # from ggplot2 (but not exported by ggplot2)
 
 `%||%` <- function(a, b) {
